@@ -83,7 +83,7 @@ class Exceptions:
 
 class BatchClient(BaseClient):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/batch.html#Batch.Client)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/batch.html#Batch.Client)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_batch/client.html)
     """
 
@@ -99,7 +99,7 @@ class BatchClient(BaseClient):
         """
         Check if an operation can be paginated.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/batch.html#Batch.Client.can_paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/batch.html#Batch.Client.can_paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_batch/client.html#can_paginate)
         """
 
@@ -107,7 +107,7 @@ class BatchClient(BaseClient):
         """
         Cancels a job in an Batch job queue.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/batch.html#Batch.Client.cancel_job)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/batch.html#Batch.Client.cancel_job)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_batch/client.html#cancel_job)
         """
 
@@ -116,15 +116,15 @@ class BatchClient(BaseClient):
         *,
         computeEnvironmentName: str,
         type: CETypeType,
-        state: CEStateType = None,
-        computeResources: "ComputeResourceTypeDef" = None,
-        serviceRole: str = None,
-        tags: Mapping[str, str] = None
+        state: CEStateType = ...,
+        computeResources: "ComputeResourceTypeDef" = ...,
+        serviceRole: str = ...,
+        tags: Mapping[str, str] = ...
     ) -> CreateComputeEnvironmentResponseTypeDef:
         """
         Creates an Batch compute environment.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/batch.html#Batch.Client.create_compute_environment)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/batch.html#Batch.Client.create_compute_environment)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_batch/client.html#create_compute_environment)
         """
 
@@ -134,13 +134,13 @@ class BatchClient(BaseClient):
         jobQueueName: str,
         priority: int,
         computeEnvironmentOrder: Sequence["ComputeEnvironmentOrderTypeDef"],
-        state: JQStateType = None,
-        tags: Mapping[str, str] = None
+        state: JQStateType = ...,
+        tags: Mapping[str, str] = ...
     ) -> CreateJobQueueResponseTypeDef:
         """
         Creates an Batch job queue.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/batch.html#Batch.Client.create_job_queue)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/batch.html#Batch.Client.create_job_queue)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_batch/client.html#create_job_queue)
         """
 
@@ -148,7 +148,7 @@ class BatchClient(BaseClient):
         """
         Deletes an Batch compute environment.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/batch.html#Batch.Client.delete_compute_environment)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/batch.html#Batch.Client.delete_compute_environment)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_batch/client.html#delete_compute_environment)
         """
 
@@ -156,7 +156,7 @@ class BatchClient(BaseClient):
         """
         Deletes the specified job queue.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/batch.html#Batch.Client.delete_job_queue)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/batch.html#Batch.Client.delete_job_queue)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_batch/client.html#delete_job_queue)
         """
 
@@ -164,47 +164,47 @@ class BatchClient(BaseClient):
         """
         Deregisters an Batch job definition.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/batch.html#Batch.Client.deregister_job_definition)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/batch.html#Batch.Client.deregister_job_definition)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_batch/client.html#deregister_job_definition)
         """
 
     def describe_compute_environments(
         self,
         *,
-        computeEnvironments: Sequence[str] = None,
-        maxResults: int = None,
-        nextToken: str = None
+        computeEnvironments: Sequence[str] = ...,
+        maxResults: int = ...,
+        nextToken: str = ...
     ) -> DescribeComputeEnvironmentsResponseTypeDef:
         """
         Describes one or more of your compute environments.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/batch.html#Batch.Client.describe_compute_environments)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/batch.html#Batch.Client.describe_compute_environments)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_batch/client.html#describe_compute_environments)
         """
 
     def describe_job_definitions(
         self,
         *,
-        jobDefinitions: Sequence[str] = None,
-        maxResults: int = None,
-        jobDefinitionName: str = None,
-        status: str = None,
-        nextToken: str = None
+        jobDefinitions: Sequence[str] = ...,
+        maxResults: int = ...,
+        jobDefinitionName: str = ...,
+        status: str = ...,
+        nextToken: str = ...
     ) -> DescribeJobDefinitionsResponseTypeDef:
         """
         Describes a list of job definitions.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/batch.html#Batch.Client.describe_job_definitions)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/batch.html#Batch.Client.describe_job_definitions)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_batch/client.html#describe_job_definitions)
         """
 
     def describe_job_queues(
-        self, *, jobQueues: Sequence[str] = None, maxResults: int = None, nextToken: str = None
+        self, *, jobQueues: Sequence[str] = ..., maxResults: int = ..., nextToken: str = ...
     ) -> DescribeJobQueuesResponseTypeDef:
         """
         Describes one or more of your job queues.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/batch.html#Batch.Client.describe_job_queues)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/batch.html#Batch.Client.describe_job_queues)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_batch/client.html#describe_job_queues)
         """
 
@@ -212,39 +212,39 @@ class BatchClient(BaseClient):
         """
         .
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/batch.html#Batch.Client.describe_jobs)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/batch.html#Batch.Client.describe_jobs)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_batch/client.html#describe_jobs)
         """
 
     def generate_presigned_url(
         self,
         ClientMethod: str,
-        Params: Mapping[str, Any] = None,
+        Params: Mapping[str, Any] = ...,
         ExpiresIn: int = 3600,
-        HttpMethod: str = None,
+        HttpMethod: str = ...,
     ) -> str:
         """
         Generate a presigned url given a client, its method, and arguments.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/batch.html#Batch.Client.generate_presigned_url)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/batch.html#Batch.Client.generate_presigned_url)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_batch/client.html#generate_presigned_url)
         """
 
     def list_jobs(
         self,
         *,
-        jobQueue: str = None,
-        arrayJobId: str = None,
-        multiNodeJobId: str = None,
-        jobStatus: JobStatusType = None,
-        maxResults: int = None,
-        nextToken: str = None,
-        filters: Sequence["KeyValuesPairTypeDef"] = None
+        jobQueue: str = ...,
+        arrayJobId: str = ...,
+        multiNodeJobId: str = ...,
+        jobStatus: JobStatusType = ...,
+        maxResults: int = ...,
+        nextToken: str = ...,
+        filters: Sequence["KeyValuesPairTypeDef"] = ...
     ) -> ListJobsResponseTypeDef:
         """
         Returns a list of Batch jobs.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/batch.html#Batch.Client.list_jobs)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/batch.html#Batch.Client.list_jobs)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_batch/client.html#list_jobs)
         """
 
@@ -252,7 +252,7 @@ class BatchClient(BaseClient):
         """
         Lists the tags for an Batch resource.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/batch.html#Batch.Client.list_tags_for_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/batch.html#Batch.Client.list_tags_for_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_batch/client.html#list_tags_for_resource)
         """
 
@@ -261,19 +261,19 @@ class BatchClient(BaseClient):
         *,
         jobDefinitionName: str,
         type: JobDefinitionTypeType,
-        parameters: Mapping[str, str] = None,
-        containerProperties: "ContainerPropertiesTypeDef" = None,
-        nodeProperties: "NodePropertiesTypeDef" = None,
-        retryStrategy: "RetryStrategyTypeDef" = None,
-        propagateTags: bool = None,
-        timeout: "JobTimeoutTypeDef" = None,
-        tags: Mapping[str, str] = None,
-        platformCapabilities: Sequence[PlatformCapabilityType] = None
+        parameters: Mapping[str, str] = ...,
+        containerProperties: "ContainerPropertiesTypeDef" = ...,
+        nodeProperties: "NodePropertiesTypeDef" = ...,
+        retryStrategy: "RetryStrategyTypeDef" = ...,
+        propagateTags: bool = ...,
+        timeout: "JobTimeoutTypeDef" = ...,
+        tags: Mapping[str, str] = ...,
+        platformCapabilities: Sequence[PlatformCapabilityType] = ...
     ) -> RegisterJobDefinitionResponseTypeDef:
         """
         Registers an Batch job definition.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/batch.html#Batch.Client.register_job_definition)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/batch.html#Batch.Client.register_job_definition)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_batch/client.html#register_job_definition)
         """
 
@@ -283,20 +283,20 @@ class BatchClient(BaseClient):
         jobName: str,
         jobQueue: str,
         jobDefinition: str,
-        arrayProperties: "ArrayPropertiesTypeDef" = None,
-        dependsOn: Sequence["JobDependencyTypeDef"] = None,
-        parameters: Mapping[str, str] = None,
-        containerOverrides: "ContainerOverridesTypeDef" = None,
-        nodeOverrides: "NodeOverridesTypeDef" = None,
-        retryStrategy: "RetryStrategyTypeDef" = None,
-        propagateTags: bool = None,
-        timeout: "JobTimeoutTypeDef" = None,
-        tags: Mapping[str, str] = None
+        arrayProperties: "ArrayPropertiesTypeDef" = ...,
+        dependsOn: Sequence["JobDependencyTypeDef"] = ...,
+        parameters: Mapping[str, str] = ...,
+        containerOverrides: "ContainerOverridesTypeDef" = ...,
+        nodeOverrides: "NodeOverridesTypeDef" = ...,
+        retryStrategy: "RetryStrategyTypeDef" = ...,
+        propagateTags: bool = ...,
+        timeout: "JobTimeoutTypeDef" = ...,
+        tags: Mapping[str, str] = ...
     ) -> SubmitJobResponseTypeDef:
         """
         Submits an Batch job from a job definition.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/batch.html#Batch.Client.submit_job)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/batch.html#Batch.Client.submit_job)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_batch/client.html#submit_job)
         """
 
@@ -304,7 +304,7 @@ class BatchClient(BaseClient):
         """
         Associates the specified tags to a resource with the specified `resourceArn`.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/batch.html#Batch.Client.tag_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/batch.html#Batch.Client.tag_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_batch/client.html#tag_resource)
         """
 
@@ -312,7 +312,7 @@ class BatchClient(BaseClient):
         """
         Terminates a job in a job queue.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/batch.html#Batch.Client.terminate_job)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/batch.html#Batch.Client.terminate_job)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_batch/client.html#terminate_job)
         """
 
@@ -320,7 +320,7 @@ class BatchClient(BaseClient):
         """
         Deletes specified tags from an Batch resource.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/batch.html#Batch.Client.untag_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/batch.html#Batch.Client.untag_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_batch/client.html#untag_resource)
         """
 
@@ -328,14 +328,14 @@ class BatchClient(BaseClient):
         self,
         *,
         computeEnvironment: str,
-        state: CEStateType = None,
-        computeResources: "ComputeResourceUpdateTypeDef" = None,
-        serviceRole: str = None
+        state: CEStateType = ...,
+        computeResources: "ComputeResourceUpdateTypeDef" = ...,
+        serviceRole: str = ...
     ) -> UpdateComputeEnvironmentResponseTypeDef:
         """
         Updates an Batch compute environment.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/batch.html#Batch.Client.update_compute_environment)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/batch.html#Batch.Client.update_compute_environment)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_batch/client.html#update_compute_environment)
         """
 
@@ -343,14 +343,14 @@ class BatchClient(BaseClient):
         self,
         *,
         jobQueue: str,
-        state: JQStateType = None,
-        priority: int = None,
-        computeEnvironmentOrder: Sequence["ComputeEnvironmentOrderTypeDef"] = None
+        state: JQStateType = ...,
+        priority: int = ...,
+        computeEnvironmentOrder: Sequence["ComputeEnvironmentOrderTypeDef"] = ...
     ) -> UpdateJobQueueResponseTypeDef:
         """
         Updates a job queue.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/batch.html#Batch.Client.update_job_queue)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/batch.html#Batch.Client.update_job_queue)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_batch/client.html#update_job_queue)
         """
 
@@ -359,7 +359,7 @@ class BatchClient(BaseClient):
         self, operation_name: Literal["describe_compute_environments"]
     ) -> DescribeComputeEnvironmentsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/batch.html#Batch.Paginator.DescribeComputeEnvironments)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/batch.html#Batch.Paginator.DescribeComputeEnvironments)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_batch/paginators.html#describecomputeenvironmentspaginator)
         """
 
@@ -368,7 +368,7 @@ class BatchClient(BaseClient):
         self, operation_name: Literal["describe_job_definitions"]
     ) -> DescribeJobDefinitionsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/batch.html#Batch.Paginator.DescribeJobDefinitions)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/batch.html#Batch.Paginator.DescribeJobDefinitions)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_batch/paginators.html#describejobdefinitionspaginator)
         """
 
@@ -377,13 +377,13 @@ class BatchClient(BaseClient):
         self, operation_name: Literal["describe_job_queues"]
     ) -> DescribeJobQueuesPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/batch.html#Batch.Paginator.DescribeJobQueues)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/batch.html#Batch.Paginator.DescribeJobQueues)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_batch/paginators.html#describejobqueuespaginator)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_jobs"]) -> ListJobsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/batch.html#Batch.Paginator.ListJobs)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/batch.html#Batch.Paginator.ListJobs)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_batch/paginators.html#listjobspaginator)
         """
